---
title: <span class="badge builder"></span> UpdateConfig
---
# <span class="badge builder"></span> UpdateConfig

## Constructor

```python
UpdateConfig()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> debug.UpdateConfig
```

### <span class="badge object-method"></span> data_changed

```python
def data_changed(data_changed: bool) -> typing.Self
```

### <span class="badge object-method"></span> render

```python
def render(render: bool) -> typing.Self
```

### <span class="badge object-method"></span> schema_changed

```python
def schema_changed(schema_changed: bool) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [UpdateConfig](./object-UpdateConfig.md)
